searchData={"items":[{"type":"module","title":"WikitextEx","doc":"WikitextEx - A robust MediaWiki wikitext parser for Elixir.\n\nWikitextEx provides functionality to parse MediaWiki wikitext markup into\nstructured AST nodes, making it easy to process and analyze wiki content.","ref":"WikitextEx.html"},{"type":"module","title":"Quick Start - WikitextEx","doc":"iex> # Parse wikitext into AST\n    iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"'''Bold''' and ''italic'' text\")\n    iex> # Work with the parsed AST\n    iex> templates = WikitextEx.find_templates(ast)\n    iex> length(templates)\n    0\n    iex> text_content = WikitextEx.extract_text(ast)\n    iex> text_content\n    \"Bold and italic text\"","ref":"WikitextEx.html#module-quick-start"},{"type":"module","title":"Main Functions - WikitextEx","doc":"- `parse/1` - Parse wikitext string into AST\n- `find_templates/1` - Extract all template nodes from AST\n- `find_links/1` - Extract all link nodes from AST\n- `extract_text/1` - Get plain text content from AST","ref":"WikitextEx.html#module-main-functions"},{"type":"function","title":"WikitextEx.extract_text/1","doc":"Extract plain text content from AST nodes.\n\nThis function recursively traverses the AST and extracts all text content,\nignoring markup and structure.","ref":"WikitextEx.html#extract_text/1"},{"type":"function","title":"Examples - WikitextEx.extract_text/1","doc":"iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"'''Bold''' and ''italic'' text\")\n    iex> WikitextEx.extract_text(ast)\n    \"Bold and italic text\"","ref":"WikitextEx.html#extract_text/1-examples"},{"type":"function","title":"WikitextEx.find_headers/1","doc":"Find all header nodes in an AST.","ref":"WikitextEx.html#find_headers/1"},{"type":"function","title":"Examples - WikitextEx.find_headers/1","doc":"iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"== Header ==\\nContent\")\n    iex> headers = WikitextEx.find_headers(ast)\n    iex> length(headers)\n    1","ref":"WikitextEx.html#find_headers/1-examples"},{"type":"function","title":"WikitextEx.find_links/1","doc":"Find all link nodes in an AST (including categories and files).","ref":"WikitextEx.html#find_links/1"},{"type":"function","title":"Examples - WikitextEx.find_links/1","doc":"iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"[[Article]] [[Category:Example]]\")\n    iex> links = WikitextEx.find_links(ast)\n    iex> length(links)\n    2","ref":"WikitextEx.html#find_links/1-examples"},{"type":"function","title":"WikitextEx.find_templates/1","doc":"Find all template nodes in an AST.","ref":"WikitextEx.html#find_templates/1"},{"type":"function","title":"Examples - WikitextEx.find_templates/1","doc":"iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"{{template1}} and {{template2|arg}}\")\n    iex> templates = WikitextEx.find_templates(ast)\n    iex> length(templates)\n    2","ref":"WikitextEx.html#find_templates/1-examples"},{"type":"function","title":"WikitextEx.parse/1","doc":"Parse wikitext markup into an AST.\n\nReturns the same tuple format as NimbleParsec for consistency:\n`{:ok, ast, rest, context, position, byte_offset}` on success or\n`{:error, reason, rest, context, position, byte_offset}` on failure.","ref":"WikitextEx.html#parse/1"},{"type":"function","title":"Examples - WikitextEx.parse/1","doc":"iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"'''Bold text'''\")\n    iex> [%WikitextEx.AST{type: :bold, value: nil, children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Bold text\"}, children: []}]}] = ast\n    [%WikitextEx.AST{type: :bold, value: nil, children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Bold text\"}, children: []}]}]\n\n    iex> {:ok, ast, _, _, _, _} = WikitextEx.parse(\"{{template|arg}}\")\n    iex> [%WikitextEx.AST{type: :template, value: %WikitextEx.AST.Template{name: \"template\", args: [positional: \"arg\"]}, children: []}] = ast\n    [%WikitextEx.AST{type: :template, value: %WikitextEx.AST.Template{name: \"template\", args: [positional: \"arg\"]}, children: []}]","ref":"WikitextEx.html#parse/1-examples"},{"type":"module","title":"WikitextEx.AST","doc":"Abstract Syntax Tree (AST) structure for WikitextEx parser.\n\nThis module defines the AST node structure and all the specific node types\nthat represent different wikitext elements. Each AST node has:\n\n- `type`: An atom indicating the kind of element (`:text`, `:template`, `:link`, etc.)\n- `value`: Type-specific data stored in structured format\n- `children`: List of nested AST nodes for container elements","ref":"WikitextEx.AST.html"},{"type":"module","title":"Example - WikitextEx.AST","doc":"%WikitextEx.AST{\n      type: :template,\n      value: %WikitextEx.AST.Template{name: \"cite\", args: [...]},\n      children: []\n    }","ref":"WikitextEx.AST.html#module-example"},{"type":"module","title":"Node Types - WikitextEx.AST","doc":"The parser produces these AST node types:\n\n- Text elements: `:text`\n- Structure: `:header`, `:list_item`, `:table`, `:table_row`, `:table_cell`\n- Formatting: `:bold`, `:italic`\n- Links: `:link`, `:category`, `:file`, `:interlang_link`\n- Templates: `:template`\n- HTML: `:html_tag`, `:comment`, `:ref`, `:nowiki`","ref":"WikitextEx.AST.html#module-node-types"},{"type":"type","title":"WikitextEx.AST.t/0","doc":"","ref":"WikitextEx.AST.html#t:t/0"},{"type":"function","title":"WikitextEx.AST.text_content/1","doc":"Extract text content from AST children, useful for headers and other containers.","ref":"WikitextEx.AST.html#text_content/1"},{"type":"function","title":"Examples - WikitextEx.AST.text_content/1","doc":"iex> children = [\n    ...>   %WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Hello\"}, children: []},\n    ...>   %WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \" World\"}, children: []}\n    ...> ]\n    iex> WikitextEx.AST.text_content(children)\n    \"Hello World\"\n\n    iex> node = %WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Single text\"}, children: []}\n    iex> WikitextEx.AST.text_content(node)\n    \"Single text\"\n\n    iex> bold_node = %WikitextEx.AST{\n    ...>   type: :bold,\n    ...>   value: nil,\n    ...>   children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Bold text\"}, children: []}]\n    ...> }\n    iex> WikitextEx.AST.text_content(bold_node)\n    \"Bold text\"","ref":"WikitextEx.AST.html#text_content/1-examples"},{"type":"type","title":"WikitextEx.AST.type/0","doc":"","ref":"WikitextEx.AST.html#t:type/0"},{"type":"type","title":"WikitextEx.AST.value/0","doc":"","ref":"WikitextEx.AST.html#t:value/0"},{"type":"module","title":"WikitextEx.AST.Category","doc":"A category inclusion","ref":"WikitextEx.AST.Category.html"},{"type":"type","title":"WikitextEx.AST.Category.t/0","doc":"","ref":"WikitextEx.AST.Category.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Comment","doc":"An HTML comment","ref":"WikitextEx.AST.Comment.html"},{"type":"type","title":"WikitextEx.AST.Comment.t/0","doc":"","ref":"WikitextEx.AST.Comment.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.File","doc":"A file embedding: name and optional parameters","ref":"WikitextEx.AST.File.html"},{"type":"type","title":"WikitextEx.AST.File.t/0","doc":"","ref":"WikitextEx.AST.File.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Header","doc":"A level‐N header","ref":"WikitextEx.AST.Header.html"},{"type":"type","title":"WikitextEx.AST.Header.t/0","doc":"","ref":"WikitextEx.AST.Header.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.HtmlTag","doc":"An HTML tag with optional attributes","ref":"WikitextEx.AST.HtmlTag.html"},{"type":"type","title":"WikitextEx.AST.HtmlTag.t/0","doc":"","ref":"WikitextEx.AST.HtmlTag.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.InterlangLink","doc":"An inter‐language link","ref":"WikitextEx.AST.InterlangLink.html"},{"type":"type","title":"WikitextEx.AST.InterlangLink.t/0","doc":"","ref":"WikitextEx.AST.InterlangLink.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Link","doc":"A wiki link: target page and optional display text","ref":"WikitextEx.AST.Link.html"},{"type":"type","title":"WikitextEx.AST.Link.t/0","doc":"","ref":"WikitextEx.AST.Link.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.ListItem","doc":"A list item (ordered or unordered) with nesting level","ref":"WikitextEx.AST.ListItem.html"},{"type":"type","title":"WikitextEx.AST.ListItem.list_type/0","doc":"","ref":"WikitextEx.AST.ListItem.html#t:list_type/0"},{"type":"type","title":"WikitextEx.AST.ListItem.t/0","doc":"","ref":"WikitextEx.AST.ListItem.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Nowiki","doc":"Nowiki content that should not be parsed","ref":"WikitextEx.AST.Nowiki.html"},{"type":"type","title":"WikitextEx.AST.Nowiki.t/0","doc":"","ref":"WikitextEx.AST.Nowiki.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Ref","doc":"A reference tag with optional name and group","ref":"WikitextEx.AST.Ref.html"},{"type":"type","title":"WikitextEx.AST.Ref.t/0","doc":"","ref":"WikitextEx.AST.Ref.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Table","doc":"A MediaWiki table with optional attributes","ref":"WikitextEx.AST.Table.html"},{"type":"type","title":"WikitextEx.AST.Table.t/0","doc":"","ref":"WikitextEx.AST.Table.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.TableCell","doc":"A table cell (header or data) with optional attributes","ref":"WikitextEx.AST.TableCell.html"},{"type":"type","title":"WikitextEx.AST.TableCell.cell_type/0","doc":"","ref":"WikitextEx.AST.TableCell.html#t:cell_type/0"},{"type":"type","title":"WikitextEx.AST.TableCell.t/0","doc":"","ref":"WikitextEx.AST.TableCell.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.TableRow","doc":"A table row with optional attributes","ref":"WikitextEx.AST.TableRow.html"},{"type":"type","title":"WikitextEx.AST.TableRow.t/0","doc":"","ref":"WikitextEx.AST.TableRow.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Template","doc":"A template invocation with name and keyword args","ref":"WikitextEx.AST.Template.html"},{"type":"type","title":"WikitextEx.AST.Template.args/0","doc":"","ref":"WikitextEx.AST.Template.html#t:args/0"},{"type":"type","title":"WikitextEx.AST.Template.t/0","doc":"","ref":"WikitextEx.AST.Template.html#t:t/0"},{"type":"module","title":"WikitextEx.AST.Text","doc":"Plain text node","ref":"WikitextEx.AST.Text.html"},{"type":"type","title":"WikitextEx.AST.Text.t/0","doc":"","ref":"WikitextEx.AST.Text.html#t:t/0"},{"type":"module","title":"WikitextEx.Parser","doc":"A robust MediaWiki wikitext parser that converts wikitext markup into structured AST nodes.\n\nThis parser supports the complete range of MediaWiki wikitext syntax including:\n- Headers (=, ==, ===, etc.)\n- Templates with named and positional arguments\n- Internal links, categories, files, and interlanguage links\n- Text formatting (bold, italic, combinations)\n- Lists (ordered and unordered with nesting)\n- Tables with headers and data cells\n- HTML tags and comments\n- Reference tags and nowiki sections","ref":"WikitextEx.Parser.html"},{"type":"module","title":"Usage - WikitextEx.Parser","doc":"iex> {:ok, ast, _, _, _, _} = WikitextEx.Parser.parse(\"'''Bold''' text\")\n    iex> ast\n    [\n      %WikitextEx.AST{type: :bold, value: nil, children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Bold\"}, children: []}]},\n      %WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \" text\"}, children: []}\n    ]","ref":"WikitextEx.Parser.html#module-usage"},{"type":"module","title":"Parser Architecture - WikitextEx.Parser","doc":"The parser uses NimbleParsec combinators to build a comprehensive grammar that handles:\n- Proper precedence for nested formatting\n- Context-aware parsing for different wikitext environments\n- Robust error recovery and graceful degradation","ref":"WikitextEx.Parser.html#module-parser-architecture"},{"type":"function","title":"WikitextEx.Parser.bold_italic_text/2","doc":"Parses the given `binary` as bold_italic_text.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the bold_italic_text (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#bold_italic_text/2"},{"type":"function","title":"Options - WikitextEx.Parser.bold_italic_text/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#bold_italic_text/2-options"},{"type":"function","title":"WikitextEx.Parser.bold_text/2","doc":"Parses the given `binary` as bold_text.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the bold_text (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#bold_text/2"},{"type":"function","title":"Options - WikitextEx.Parser.bold_text/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#bold_text/2-options"},{"type":"function","title":"WikitextEx.Parser.container_html_tag/2","doc":"Parses the given `binary` as container_html_tag.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the container_html_tag (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#container_html_tag/2"},{"type":"function","title":"Options - WikitextEx.Parser.container_html_tag/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#container_html_tag/2-options"},{"type":"function","title":"WikitextEx.Parser.container_ref_tag/2","doc":"Parses the given `binary` as container_ref_tag.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the container_ref_tag (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#container_ref_tag/2"},{"type":"function","title":"Options - WikitextEx.Parser.container_ref_tag/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#container_ref_tag/2-options"},{"type":"function","title":"WikitextEx.Parser.header/2","doc":"Parses the given `binary` as header.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the header (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#header/2"},{"type":"function","title":"Options - WikitextEx.Parser.header/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#header/2-options"},{"type":"function","title":"WikitextEx.Parser.html_comment/2","doc":"Parses the given `binary` as html_comment.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the html_comment (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#html_comment/2"},{"type":"function","title":"Options - WikitextEx.Parser.html_comment/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#html_comment/2-options"},{"type":"function","title":"WikitextEx.Parser.italic_text/2","doc":"Parses the given `binary` as italic_text.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the italic_text (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#italic_text/2"},{"type":"function","title":"Options - WikitextEx.Parser.italic_text/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#italic_text/2-options"},{"type":"function","title":"WikitextEx.Parser.link/2","doc":"Parses the given `binary` as link.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the link (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#link/2"},{"type":"function","title":"Options - WikitextEx.Parser.link/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#link/2-options"},{"type":"function","title":"WikitextEx.Parser.list_item/2","doc":"Parses the given `binary` as list_item.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the list_item (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#list_item/2"},{"type":"function","title":"Options - WikitextEx.Parser.list_item/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#list_item/2-options"},{"type":"function","title":"WikitextEx.Parser.nowiki_tag/2","doc":"Parses the given `binary` as nowiki_tag.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the nowiki_tag (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#nowiki_tag/2"},{"type":"function","title":"Options - WikitextEx.Parser.nowiki_tag/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#nowiki_tag/2-options"},{"type":"function","title":"WikitextEx.Parser.parse/2","doc":"Parses the given `binary` as parse.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the parse (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#parse/2"},{"type":"function","title":"Options - WikitextEx.Parser.parse/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#parse/2-options"},{"type":"function","title":"WikitextEx.Parser.self_closing_html_tag/2","doc":"Parses the given `binary` as self_closing_html_tag.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the self_closing_html_tag (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#self_closing_html_tag/2"},{"type":"function","title":"Options - WikitextEx.Parser.self_closing_html_tag/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#self_closing_html_tag/2-options"},{"type":"function","title":"WikitextEx.Parser.self_closing_ref_tag/2","doc":"Parses the given `binary` as self_closing_ref_tag.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the self_closing_ref_tag (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#self_closing_ref_tag/2"},{"type":"function","title":"Options - WikitextEx.Parser.self_closing_ref_tag/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#self_closing_ref_tag/2-options"},{"type":"function","title":"WikitextEx.Parser.table/2","doc":"Parses the given `binary` as table.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the table (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#table/2"},{"type":"function","title":"Options - WikitextEx.Parser.table/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#table/2-options"},{"type":"function","title":"WikitextEx.Parser.table_cell_attributes/2","doc":"Parses the given `binary` as table_cell_attributes.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the table_cell_attributes (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#table_cell_attributes/2"},{"type":"function","title":"Options - WikitextEx.Parser.table_cell_attributes/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#table_cell_attributes/2-options"},{"type":"function","title":"WikitextEx.Parser.table_cell_content/2","doc":"Parses the given `binary` as table_cell_content.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the table_cell_content (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#table_cell_content/2"},{"type":"function","title":"Options - WikitextEx.Parser.table_cell_content/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#table_cell_content/2-options"},{"type":"function","title":"WikitextEx.Parser.table_data_cell/2","doc":"Parses the given `binary` as table_data_cell.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the table_data_cell (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#table_data_cell/2"},{"type":"function","title":"Options - WikitextEx.Parser.table_data_cell/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#table_data_cell/2-options"},{"type":"function","title":"WikitextEx.Parser.table_header_cell/2","doc":"Parses the given `binary` as table_header_cell.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the table_header_cell (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#table_header_cell/2"},{"type":"function","title":"Options - WikitextEx.Parser.table_header_cell/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#table_header_cell/2-options"},{"type":"function","title":"WikitextEx.Parser.template/2","doc":"Parses the given `binary` as template.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the template (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#template/2"},{"type":"function","title":"Options - WikitextEx.Parser.template/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#template/2-options"},{"type":"function","title":"WikitextEx.Parser.template_value/2","doc":"Parses the given `binary` as template_value.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the template_value (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"WikitextEx.Parser.html#template_value/2"},{"type":"function","title":"Options - WikitextEx.Parser.template_value/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"WikitextEx.Parser.html#template_value/2-options"},{"type":"function","title":"WikitextEx.Parser.to_attribute/1","doc":"","ref":"WikitextEx.Parser.html#to_attribute/1"},{"type":"function","title":"WikitextEx.Parser.to_attributes/1","doc":"","ref":"WikitextEx.Parser.html#to_attributes/1"},{"type":"function","title":"WikitextEx.Parser.to_bare_value/1","doc":"","ref":"WikitextEx.Parser.html#to_bare_value/1"},{"type":"function","title":"WikitextEx.Parser.to_bold/1","doc":"","ref":"WikitextEx.Parser.html#to_bold/1"},{"type":"function","title":"WikitextEx.Parser.to_bold_italic/1","doc":"","ref":"WikitextEx.Parser.html#to_bold_italic/1"},{"type":"function","title":"WikitextEx.Parser.to_cell_content/1","doc":"","ref":"WikitextEx.Parser.html#to_cell_content/1"},{"type":"function","title":"WikitextEx.Parser.to_container_html_tag/1","doc":"","ref":"WikitextEx.Parser.html#to_container_html_tag/1"},{"type":"function","title":"WikitextEx.Parser.to_container_ref_tag/1","doc":"","ref":"WikitextEx.Parser.html#to_container_ref_tag/1"},{"type":"function","title":"WikitextEx.Parser.to_data_cell/1","doc":"","ref":"WikitextEx.Parser.html#to_data_cell/1"},{"type":"function","title":"WikitextEx.Parser.to_header/1","doc":"","ref":"WikitextEx.Parser.html#to_header/1"},{"type":"function","title":"WikitextEx.Parser.to_header_cell/1","doc":"","ref":"WikitextEx.Parser.html#to_header_cell/1"},{"type":"function","title":"WikitextEx.Parser.to_html_comment/1","doc":"","ref":"WikitextEx.Parser.html#to_html_comment/1"},{"type":"function","title":"WikitextEx.Parser.to_italic/1","doc":"","ref":"WikitextEx.Parser.html#to_italic/1"},{"type":"function","title":"WikitextEx.Parser.to_kv/1","doc":"","ref":"WikitextEx.Parser.html#to_kv/1"},{"type":"function","title":"WikitextEx.Parser.to_link/1","doc":"","ref":"WikitextEx.Parser.html#to_link/1"},{"type":"function","title":"WikitextEx.Parser.to_list_item/1","doc":"","ref":"WikitextEx.Parser.html#to_list_item/1"},{"type":"function","title":"WikitextEx.Parser.to_nowiki/1","doc":"","ref":"WikitextEx.Parser.html#to_nowiki/1"},{"type":"function","title":"WikitextEx.Parser.to_self_closing_html_tag/1","doc":"","ref":"WikitextEx.Parser.html#to_self_closing_html_tag/1"},{"type":"function","title":"WikitextEx.Parser.to_self_closing_ref_tag/1","doc":"","ref":"WikitextEx.Parser.html#to_self_closing_ref_tag/1"},{"type":"function","title":"WikitextEx.Parser.to_table_with_nimble_parsec/1","doc":"","ref":"WikitextEx.Parser.html#to_table_with_nimble_parsec/1"},{"type":"function","title":"WikitextEx.Parser.to_template/1","doc":"","ref":"WikitextEx.Parser.html#to_template/1"},{"type":"function","title":"WikitextEx.Parser.to_text/1","doc":"","ref":"WikitextEx.Parser.html#to_text/1"},{"type":"extras","title":"WikitextEx","doc":"# WikitextEx\n\n[![Hex.pm](https://img.shields.io/hexpm/v/wikitext_ex.svg)](https://hex.pm/packages/wikitext_ex)\n[![Documentation](https://img.shields.io/badge/docs-hexdocs-blue.svg)](https://hexdocs.pm/wikitext_ex)\n\nA MediaWiki wikitext parser for Elixir that converts wikitext markup into structured AST nodes. WikitextEx supports templates, links, formatting, tables, and other wikitext elements commonly found in MediaWiki content.\n\n> **⚠️ Current Status: Beta** - WikitextEx successfully parses many common wikitext patterns but has known limitations with certain edge cases. See [Known Limitations](#known-limitations) for details.","ref":"readme.html"},{"type":"extras","title":"Features - WikitextEx","doc":"- **Complete Wikitext Support**: Parse headers, links, templates, formatting (bold/italic), lists, tables, and more\n- **Structured AST**: Clean, typed AST nodes for easy manipulation and analysis\n- **Template Parsing**: Full support for MediaWiki template syntax with named and positional arguments\n- **HTML Tag Support**: Parse HTML tags, comments, and special tags like ` ` and ` `\n- **Table Parsing**: Complete MediaWiki table syntax support with headers and data cells\n- **Robust Formatting**: Handles complex bold/italic combinations and nested formatting\n- **Link Types**: Support for internal links, categories, files, and interlanguage links","ref":"readme.html#features"},{"type":"extras","title":"Installation - WikitextEx","doc":"Add `wikitext_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:wikitext_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - WikitextEx","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Parsing - WikitextEx","doc":"```elixir\n# Parse simple wikitext\n{:ok, ast, _, _, _, _} = WikitextEx.Parser.parse(\"'''Bold text''' and ''italic text''\")\n\n# The result is a list of AST nodes\n[\n  %WikitextEx.AST{type: :bold, children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Bold text\"}}]},\n  %WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \" and \"}},\n  %WikitextEx.AST{type: :italic, children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"italic text\"}}]}\n]\n```","ref":"readme.html#basic-parsing"},{"type":"extras","title":"Templates - WikitextEx","doc":"```elixir\n# Parse templates with arguments\n{:ok, ast, _, _, _, _} = WikitextEx.Parser.parse(\"{{template|arg1|key=value}}\")\n\n# Results in template AST node\n%WikitextEx.AST{\n  type: :template,\n  value: %WikitextEx.AST.Template{\n    name: \"template\",\n    args: [\n      {:positional, \"arg1\"},\n      {:named, %{\"key\" => \"value\"}}\n    ]\n  }\n}\n```","ref":"readme.html#templates"},{"type":"extras","title":"Links and Categories - WikitextEx","doc":"```elixir\n# Parse various link types\n{:ok, ast, _, _, _, _} = WikitextEx.Parser.parse(\"[[Article]] [[Category:Example]] [[File:image.jpg|thumb]]\")\n\n# Results in different AST node types:\n# - :link for regular internal links\n# - :category for category links\n# - :file for file/media links\n```","ref":"readme.html#links-and-categories"},{"type":"extras","title":"Headers - WikitextEx","doc":"```elixir\n# Parse headers\n{:ok, ast, _, _, _, _} = WikitextEx.Parser.parse(\"== Section Header ==\")\n\n%WikitextEx.AST{\n  type: :header,\n  value: %WikitextEx.AST.Header{level: 2},\n  children: [%WikitextEx.AST{type: :text, value: %WikitextEx.AST.Text{content: \"Section Header\"}}]\n}\n```","ref":"readme.html#headers"},{"type":"extras","title":"Tables - WikitextEx","doc":"```elixir\nwikitext = \"\"\"\n{|\n! Header 1 !! Header 2\n|-\n| Cell 1 || Cell 2\n|}\n\"\"\"\n\n{:ok, ast, _, _, _, _} = WikitextEx.Parser.parse(wikitext)\n# Results in table AST with rows and cells\n```","ref":"readme.html#tables"},{"type":"extras","title":"AST Structure - WikitextEx","doc":"WikitextEx produces a structured AST where each node follows this pattern:\n\n```elixir\n%WikitextEx.AST{\n  type: atom(),           # The type of element (:text, :template, :link, etc.)\n  value: struct() | nil,  # Type-specific data (e.g., %AST.Text{content: \"...\"})\n  children: [%AST{}]      # Nested AST nodes\n}\n```","ref":"readme.html#ast-structure"},{"type":"extras","title":"Supported AST Node Types - WikitextEx","doc":"- `:text` - Plain text content\n- `:header` - Headers (=, ==, ===, etc.)\n- `:template` - Template invocations ({{template|args}})\n- `:link` - Internal wiki links ([[Page]])\n- `:category` - Category links ([[Category:Name]])\n- `:file` - File/media links ([[File:image.jpg]])\n- `:interlang_link` - Interlanguage links ([[de:Page]])\n- `:bold` - Bold formatting ('''text''')\n- `:italic` - Italic formatting (''text'')\n- `:list_item` - List items (\\* or #)\n- `:table` - Tables ({| ... |})\n- `:table_row` - Table rows\n- `:table_cell` - Table cells (header or data)\n- `:html_tag` - HTML tags ( ,  , etc.)\n- `:ref` - Reference tags ( )\n- `:comment` - HTML comments (<!-- -->)\n- `:nowiki` - Nowiki sections ( )","ref":"readme.html#supported-ast-node-types"},{"type":"extras","title":"Advanced Usage - WikitextEx","doc":"","ref":"readme.html#advanced-usage"},{"type":"extras","title":"Working with AST - WikitextEx","doc":"```elixir\n# Extract text content from headers or other containers\nWikitextEx.AST.text_content(ast_node.children)\n\n# Navigate the AST tree\ndefmodule WikitextWalker do\n  def find_templates(ast_nodes) do\n    Enum.flat_map(ast_nodes, fn\n      %WikitextEx.AST{type: :template} = node -> [node]\n      %WikitextEx.AST{children: children} -> find_templates(children)\n      _ -> []\n    end)\n  end\nend\n```","ref":"readme.html#working-with-ast"},{"type":"extras","title":"Custom Processing - WikitextEx","doc":"```elixir\ndefmodule WikitextProcessor do\n  def extract_links(wikitext) do\n    case WikitextEx.Parser.parse(wikitext) do\n      {:ok, ast, _, _, _, _} ->\n        ast\n        |> find_links()\n        |> Enum.map(& &1.value.target)\n\n      {:error, _} ->\n        []\n    end\n  end\n\n  defp find_links(ast_nodes) do\n    Enum.flat_map(ast_nodes, fn\n      %WikitextEx.AST{type: :link} = node -> [node]\n      %WikitextEx.AST{children: children} -> find_links(children)\n      _ -> []\n    end)\n  end\nend\n```","ref":"readme.html#custom-processing"},{"type":"extras","title":"Development - WikitextEx","doc":"```bash\n# Clone the repository\ngit clone https://github.com/your-username/wikitext_ex.git\ncd wikitext_ex\n\n# Install dependencies\nmix deps.get\n\n# Run tests\nmix test\n\n# Generate documentation\nmix docs\n```","ref":"readme.html#development"},{"type":"extras","title":"Known Limitations - WikitextEx","doc":"WikitextEx works well for typical wiki content, but has some known limitations:","ref":"readme.html#known-limitations"},{"type":"extras","title":"Parser Edge Cases - WikitextEx","doc":"- **Complex whitespace handling**: Some complex whitespace patterns may not parse correctly\n- **Deeply nested structures**: Very deeply nested content may cause parsing issues\n- **Advanced MediaWiki syntax**: Some advanced or rarely-used MediaWiki features are not yet supported\n- **Large content blocks**: Performance may degrade with extremely large wikitext files","ref":"readme.html#parser-edge-cases"},{"type":"extras","title":"Parsing Behavior - WikitextEx","doc":"- The parser may return partial results with unparsed content in the `rest` field for complex edge cases\n- Most common wikitext patterns parse successfully","ref":"readme.html#parsing-behavior"},{"type":"extras","title":"Recommendations - WikitextEx","doc":"- **Test with your content**: Always test WikitextEx with your specific wikitext before production use\n- **Handle partial parsing**: Check the `rest` field in parse results for unparsed content\n- **Report issues**: Please report parsing failures with examples to help improve the parser","ref":"readme.html#recommendations"},{"type":"extras","title":"Testing - WikitextEx","doc":"WikitextEx includes a comprehensive test suite with 58 tests covering various wikitext patterns and edge cases. Run the tests with:\n\n```bash\nmix test\n```","ref":"readme.html#testing"},{"type":"extras","title":"Contributing - WikitextEx","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n3. Write tests for your changes\n4. Ensure all tests pass (`mix test`)\n5. Commit your changes (`git commit -am 'Add amazing feature'`)\n6. Push to the branch (`git push origin feature/amazing-feature`)\n7. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - WikitextEx","doc":"This project is licensed under the MIT License - see the [LICENSE](https://github.com/phiilu/wikitext_ex/blob/main/LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - WikitextEx","doc":"- Built with [NimbleParsec](https://github.com/dashbitco/nimble_parsec) for robust parsing\n- Inspired by MediaWiki's wikitext specification\n- Designed for use with Wikipedia and other MediaWiki-based wikis","ref":"readme.html#acknowledgments"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [0.1.1] - 2025-07-25","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Comprehensive doctests for all modules (11 doctests total)\n- New test file `test/doctest_test.exs` to run doctests for all modules\n- Doctests for `WikitextEx.AST.text_content/1` function\n- Executable doctests converted from Quick Start examples","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Broken doctests in `WikitextEx.parse/1` with correct AST structure\n- Doctests in `WikitextEx.Parser` module\n- Documentation examples now properly executable as tests","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Enhanced documentation with working code examples\n- All 11 doctests now pass alongside existing 58 tests\n\n## [0.1.0] - 2025-01-25","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of WikitextEx\n- Complete MediaWiki wikitext parser using NimbleParsec\n- Support for headers, templates, links, formatting, lists, and tables\n- Structured AST with typed nodes for all wikitext elements\n- Template parsing with named and positional arguments\n- Link type differentiation (internal, category, file, interlanguage)\n- HTML tag support including ` `, ` `, and comments\n- Comprehensive test suite with 58 tests\n- Complete documentation with usage examples\n- Production-ready packaging for Hex.pm","ref":"changelog.html#added-1"},{"type":"extras","title":"Parser Features - Changelog","doc":"- Text formatting: bold (`'''`), italic (`''`), and combinations\n- Headers with 1-6 levels (`=` to `======`)\n- Internal links (`[[Page]]`) with display text support\n- Categories (`[[Category:Name]]`) and file links (`[[File:image.jpg]]`)\n- Templates (`{{template|args}}`) with full argument parsing\n- Lists (ordered `#` and unordered `*`) with nesting support\n- Tables (`{| ... |}`) with headers and data cells\n- HTML tags with attribute parsing\n- Reference tags (` `) with name and group support\n- Nowiki sections (` `) for literal text\n- HTML comments (`<!-- -->`)\n- Interlanguage links (`[[de:Page]]`)","ref":"changelog.html#parser-features"},{"type":"extras","title":"API - Changelog","doc":"- `WikitextEx.parse/1` - Main parsing function\n- `WikitextEx.find_templates/1` - Extract template nodes\n- `WikitextEx.find_links/1` - Extract link nodes  \n- `WikitextEx.find_headers/1` - Extract header nodes\n- `WikitextEx.extract_text/1` - Get plain text content\n- `WikitextEx.AST.text_content/1` - Extract text from AST children\n\n[Unreleased]: https://github.com/phiilu/wikitext_ex/compare/v0.1.1...HEAD\n[0.1.1]: https://github.com/phiilu/wikitext_ex/compare/v0.1.0...v0.1.1\n[0.1.0]: https://github.com/phiilu/wikitext_ex/releases/tag/v0.1.0","ref":"changelog.html#api"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}